# web

Web server operations (nginx/apache) on the active host/app.

Common commands:
- `navig web vhosts`
- `navig web test`
- `navig web reload`
- `navig web enable <site>` / `navig web disable <site>`

Examples:
- `navig web test`
- `navig web reload`

Tips:
- If you use HestiaCP, see: `navig web hestia --help`
